# prompt_maker


<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

This file will become your README and also the index of your
documentation.

## Developer Guide

If you are new to using `nbdev` here are some useful pointers to get you
started.

### Install prompt_maker in Development mode

``` sh
# make sure prompt_maker package is installed in development mode
$ pip install -e .

# make changes under nbs/ directory
# ...

# compile to have changes apply to prompt_maker
$ nbdev_prepare
```

## Usage

### Installation

Install latest from the GitHub
[repository](https://github.com/Gaurav-Adlakha/prompt_maker):

``` sh
$ pip install git+https://github.com/Gaurav-Adlakha/prompt_maker.git
```

or from [conda](https://anaconda.org/Gaurav-Adlakha/prompt_maker)

``` sh
$ conda install -c Gaurav-Adlakha prompt_maker
```

or from [pypi](https://pypi.org/project/prompt_maker/)

``` sh
$ pip install prompt_maker
```

### Documentation

Documentation can be found hosted on this GitHub
[repository](https://github.com/Gaurav-Adlakha/prompt_maker)’s
[pages](https://Gaurav-Adlakha.github.io/prompt_maker/). Additionally
you can find package manager specific guidelines on
[conda](https://anaconda.org/Gaurav-Adlakha/prompt_maker) and
[pypi](https://pypi.org/project/prompt_maker/) respectively.
